@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound PROcessing
  * A simple command line effect processor using LV2 plugins
  *
- * Copyright (C) 2011-2013 LV2proc development team
+ * Copyright (C) 2011-2014 Stefano D'Angelo
  *
  * See the COPYING file for license conditions.
  */
@@ -13,6 +13,7 @@
 #include <errno.h>
 #include <locale.h>
 #include <inttypes.h>
+#include <stdbool.h>
 #include <time.h>
 
 #include <math.h>
@@ -193,8 +194,7 @@ cmd_parse(int argc, char *argv[])
 		if (!strcmp(argv[i], "--version"))
 		  {
 			printf(PACKAGE " (" PACKAGE_NAME ") " VERSION "\n");
-			printf("Copyright (C) 2011-2013 LV2proc development "
-			       "team\n");
+			printf("Copyright (C) 2011-2014 Stefano D'Angelo\n");
 			printf("This is free software; see the source for "
 			       "copying conditions.  There is NO\n");
 			printf("warranty; not even for MERCHANTABILITY or "
@@ -259,7 +259,7 @@ cmd_parse(int argc, char *argv[])
 				goto cmd_parse_err;
 			  }
 
-			bool err = strtoul_nl(&frames_n, argv[++i]);
+			bool err = !strtoul_nl(&frames_n, argv[++i]);
 			if (err || (frames_n == 0))
 			  {
 				PRINT_ERROR("invalid number of frames");
